/***************************************************************************
                          latexconverter.cpp  -  description                              
                             -------------------                                         
    begin                : Sat Jul 3 1999                                           
    copyright            : (C) 1999 by Rajko Albrecht                         
    email                : Rajko.Albrecht@informatik.tu-chemnitz.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/
#ifndef rcsid
static const char rcsid[]="$Id: latexconverter.cpp,v 2.4 1999/07/30 00:30:36 ral Exp $";
const char*latexconverter_rcs(){return rcsid;}
#endif

#include "latexconverter.h"

CLatexConverter::CLatexConverter()
    :CConverter()
{
    
    count = 13;
    source_idents.resize(count);
    target_idents.resize(count);
    
    source_idents[0]="\\";
    source_idents[1]="#";
    source_idents[2]="$";
    source_idents[3]="&";
    source_idents[4]="_";
    source_idents[5]="%";
    source_idents[6]="{";
    source_idents[7]="}";
    source_idents[8]="\"";
    source_idents[9]="\'";
    source_idents[10]="<";
    source_idents[11]=">";
    source_idents[12]="\\backslash";

    target_idents[0]="\\backslash";
    target_idents[1]="\\#";
    target_idents[2]="\\$";
    target_idents[3]="\\&";
    target_idents[4]="\\_";
    target_idents[5]="\\%";
    target_idents[6]="\\{";
    target_idents[7]="\\}";
    target_idents[8]="\\symbol{34}";
    target_idents[9]="\\symbol{39}";
    target_idents[10]="$<$";
    target_idents[11]="$>$";
    target_idents[12]="$\\backslash$";
}

CLatexConverter::~CLatexConverter()
{
}
